#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_FIRSTBITSET_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_FIRSTBITSET_HPP_INCLUDED

#include <boost/simd/bitwise/include/functions/firstbitset.hpp>

#endif
